pub fn open_card(card: &Expr, pane: &str) -> Option<Expr>
Open a card into the best lens for its target: an intent/open of the card’s target, dispatched to the right lens rather than the generic card renderer.
intent/open